package sun.awt;

import java.util.Iterator;
import java.awt.IllegalComponentStateException;
import java.util.HashSet;
import java.util.Collections;
import java.util.WeakHashMap;
import java.util.Map;
import sun.util.logging.PlatformLogger;

public class SunDisplayChanger
{
    private static final PlatformLogger log;
    private Map<DisplayChangedListener, Void> listeners;
    
    public SunDisplayChanger() {
        this.listeners = Collections.synchronizedMap(new WeakHashMap(1));
    }
    
    public void add(DisplayChangedListener obj) {
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINE) && obj == null) {
            SunDisplayChanger.log.fine("Assertion (theListener != null) failed");
        }
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINER)) {
            SunDisplayChanger.log.finer("Adding listener: " + obj);
        }
        this.listeners.put(obj, null);
    }
    
    public void remove(DisplayChangedListener obj) {
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINE) && obj == null) {
            SunDisplayChanger.log.fine("Assertion (theListener != null) failed");
        }
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINER)) {
            SunDisplayChanger.log.finer("Removing listener: " + obj);
        }
        this.listeners.remove(obj);
    }
    
    public void notifyListeners() {
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINEST)) {
            SunDisplayChanger.log.finest("notifyListeners");
        }
        HashSet set;
        synchronized (this.listeners) {
            set = new HashSet(this.listeners.keySet());
        }
        for (DisplayChangedListener obj : set) {
            try {
                if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINEST)) {
                    SunDisplayChanger.log.finest("displayChanged for listener: " + obj);
                }
                obj.displayChanged();
            }
            catch (IllegalComponentStateException ex) {
                this.listeners.remove(obj);
            }
        }
    }
    
    public void notifyPaletteChanged() {
        if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINEST)) {
            SunDisplayChanger.log.finest("notifyPaletteChanged");
        }
        HashSet set;
        synchronized (this.listeners) {
            set = new HashSet(this.listeners.keySet());
        }
        for (DisplayChangedListener obj : set) {
            try {
                if (SunDisplayChanger.log.isLoggable(PlatformLogger.Level.FINEST)) {
                    SunDisplayChanger.log.finest("paletteChanged for listener: " + obj);
                }
                obj.paletteChanged();
            }
            catch (IllegalComponentStateException ex) {
                this.listeners.remove(obj);
            }
        }
    }
    
    static {
        log = PlatformLogger.getLogger("sun.awt.multiscreen.SunDisplayChanger");
    }
}
